## Plan Update

We aren't making as much progress as we would like, and so we may need to revise our plan.

### Question

This is the question we're working on answering:

{question}

### Current Hypothesis

This is the current hypothesis we were working on before getting stuck or failing:

{current_hypothesis}

### Root Cause

Consider what went wrong on this last run (the root cause of the failure) and adjust the plan accordingly.

### Revise Plan

Revise the plan to take steps to overcome prior challenges and especially avoids repeating the same mistakes. As before, the revised plan should be concise and consider our team composition.

#### Unverifiable Hypothesis

It is completely possible that the current hypothesis is unverifiable given our team composition or team member failures. Some examples:

- A team member repeatedly fails to complete a given task, and no other team member can step in given their description.
- Given their descriptions, no team member is qualified to complete a given task.
- You are considering some kind of manual, physical validation - this is not possible in the current environment; we can only use our 
  explicitly named team members as resources, and they are restricted to the tools available to them. If you are in this situation, 
  verify what tools are available by asking your team members, then consider marking the hypothesis as unverifiable if nothing can be done.

#### Team Composition

Consider the following team composition when updating the plan (do not involve any other outside people since we cannot contact anyone else):

{team_description}

#### Facts

Consider the following fact sheet when updating the plan:

{fact_sheet}

#### Previous Plan

Here is the old plan:

{plan}
